@@ -1,4 +1,6 @@
-from statsd.client import StatsClient
+from time import time
+
+from django_statsd.clients.null import StatsClient
 
 
 class StatsClient(StatsClient):
@@ -10,12 +12,13 @@ class StatsClient(StatsClient):
 
     def reset(self):
         self.cache = {}
+        self.timings = []
 
     def timing(self, stat, delta, rate=1):
         """Send new timing information. `delta` is in milliseconds."""
         stat = '%s|timing' % stat
-        self.cache.setdefault(stat, [])
-        self.cache[stat].append([delta, rate])
+        now = time() * 1000
+        self.timings.append([stat, now, delta, now + delta])
 
     def incr(self, stat, count=1, rate=1):
         """Increment a stat by `count`."""
@@ -29,5 +32,7 @@ class StatsClient(StatsClient):
         self.cache.setdefault(stat, [])
         self.cache[stat].append([-count, rate])
 
-    def _send(self, stat, value, rate):
-        pass
+    def gauge(self, stat, value, rate=1):
+        """Set a gauge value."""
+        stat = '%s|gauge' % stat
+        self.cache[stat] = [[value, rate]]
